.. image:: https://img.shields.io/pypi/v/jaraco.xkcd.svg
   :target: `PyPI link`_

.. image:: https://img.shields.io/pypi/pyversions/jaraco.xkcd.svg
   :target: `PyPI link`_

.. _PyPI link: https://pypi.org/project/jaraco.xkcd

.. image:: https://github.com/jaraco/jaraco.xkcd/workflows/Automated%20Tests/badge.svg
   :target: https://github.com/jaraco/jaraco.xkcd/actions?query=workflow%3A%22Automated+Tests%22
   :alt: Automated Tests

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/psf/black
   :alt: Code style: Black

.. .. image:: https://readthedocs.org/projects/skeleton/badge/?version=latest
..    :target: https://skeleton.readthedocs.io/en/latest/?badge=latest
